//@line 36 "/builds/tinderbox/firefox/Linux_2.4.20-28.8_Clobber/mozilla/browser/components/preferences/content.js"


const kFontNameFmtSerif         = "font.name.serif.%LANG%";
const kFontNameFmtSansSerif     = "font.name.sans-serif.%LANG%";
const kFontNameListFmtSerif     = "font.name-list.serif.%LANG%";
const kFontNameListFmtSansSerif = "font.name-list.sans-serif.%LANG%";
const kFontSizeFmtVariable      = "font.size.variable.%LANG%";

var gContentPane = {
  _pane: null,
  
  init: function ()
  {
    this._pane = document.getElementById("paneContent");
    this._rebuildFonts();
  },
  
  _rebuildFonts: function ()
  {
    var langGroupPref = document.getElementById("font.language.group");
    var isSerifPref = document.getElementById("font.default");
    this._selectLanguageGroup(langGroupPref.value, isSerifPref.value == "serif");
  },
  
  _selectLanguageGroup: function (aLanguageGroup, aIsSerif)
  {
    var prefs = [{ format   : aIsSerif ? kFontNameFmtSerif : kFontNameFmtSansSerif,
                   type     : "unichar", 
                   element  : "defaultFont",      
                   fonttype : aIsSerif ? "serif" : "sans-serif" },
                 { format   : aIsSerif ? kFontNameListFmtSerif : kFontNameListFmtSansSerif,
                   type     : "unichar", 
                   element  : null,               
                   fonttype : aIsSerif ? "serif" : "sans-serif" },
                 { format   : kFontSizeFmtVariable,      
                   type     : "int",     
                   element  : "defaultFontSize",  
                   fonttype : null }];
    var preferences = document.getElementById("contentPreferences");
    for (var i = 0; i < prefs.length; ++i) {
      var preference = document.getElementById(prefs[i].format.replace(/%LANG%/, aLanguageGroup));
      if (!preference) {
        preference = document.createElement("preference");
        var name = prefs[i].format.replace(/%LANG%/, aLanguageGroup);
        preference.id = name;
        preference.setAttribute("name", name);
        preference.setAttribute("type", prefs[i].type);
        preferences.appendChild(preference);
      }
      
      if (!prefs[i].element)
        continue;
        
      var element = document.getElementById(prefs[i].element);
      if (element) {
        element.setAttribute("preference", preference.id);
      
        if (prefs[i].fonttype)
          FontBuilder.buildFontList(aLanguageGroup, prefs[i].fonttype, element);

        preference.setElementValue(element);
      }
    }
  },

  writeEnableImagesPref: function ()
  { 
    var enableImages = document.getElementById("enableImages");
    if (enableImages.checked) {
      var enableRestricted = document.getElementById("enableRestricted");
      return enableRestricted.checked ? 3 : 1;
    }
    return 2;
  },
  
  readEnableImagesPref: function ()
  {
    var pref = document.getElementById("permissions.default.image");
    var enableRestricted = document.getElementById("enableRestricted");    
    enableRestricted.disabled = pref.value == 2;
    return (pref.value == 1 || pref.value == 3);
  },
  
  readEnableRestrictedPref: function ()
  {
    var pref = document.getElementById("permissions.default.image");
    return (pref.value == 3);
  },
  
  _exceptionsParams: {
    install: { blockVisible: false, sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "install", },
    popup:   { blockVisible: false, sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "popup"   },
    image:   { blockVisible: true,  sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "image"   },
  },
  showExceptions: function (aPermissionType)
  {
    var bundlePreferences = document.getElementById("bundlePreferences");
    var params = this._exceptionsParams[aPermissionType];
    params.windowTitle = bundlePreferences.getString(aPermissionType + "permissionstitle");
    params.introText = bundlePreferences.getString(aPermissionType + "permissionstext");
    document.documentElement.openWindow("Browser:Permissions",
                                        "chrome://browser/content/preferences/permissions.xul",
                                        "", params);
  },
  
  updateButtons: function (aButtonID, aPreferenceID)
  {
    var button = document.getElementById(aButtonID);
    var preference = document.getElementById(aPreferenceID);
    button.disabled = preference.value != true;
    return undefined;
  },
  
  readAnnoyancesEnabled: function ()
  {
    var contextMenuPref = document.getElementById("dom.event.contextmenu.enabled");
    var windowMovePref = document.getElementById("dom.disable_window_move_resize");
    var windowFlipPref = document.getElementById("dom.disable_window_flip");
    var hideStatusPref = document.getElementById("dom.disable_window_open_feature.status");
    var windowStatusPref = document.getElementById("dom.disable_window_status_change");
    return !contextMenuPref.value && windowMovePref.value && 
           windowFlipPref.value && hideStatusPref.value && 
           windowStatusPref.value;
  },
  
  writeAnnoyancesEnabled: function ()
  {
    var contextMenuPref = document.getElementById("dom.event.contextmenu.enabled");
    var windowMovePref = document.getElementById("dom.disable_window_move_resize");
    var windowFlipPref = document.getElementById("dom.disable_window_flip");
    var hideStatusPref = document.getElementById("dom.disable_window_open_feature.status");
    var windowStatusPref = document.getElementById("dom.disable_window_status_change");
    
    var disableImages = document.getElementById("disableAnnoyances");
    contextMenuPref.value = !(windowMovePref.value = windowFlipPref.value = hideStatusPref.value = windowStatusPref.value = disableImages.checked);
    return undefined;    
  },
  
  annoyancesPrefChanged: function ()
  {
    var jsannoyancesPref = document.getElementById("browser.jsannoyances.disabled");
    jsannoyancesPref.updateElements();
  },
  
  showFonts: function ()
  {
    document.documentElement.openSubDialog("chrome://browser/content/preferences/fonts.xul",
                                           "", null);  
  },

  showColors: function ()
  {
    document.documentElement.openSubDialog("chrome://browser/content/preferences/colors.xul",
                                           "", null);  
  }
};
